@@ -17,16 +17,16 @@ sub new
         map {
           # CGI->Vars joins multi-value params with a null byte.  Which sucks.
           # To avoid that behavior, we do this instead:
-          my @val = $cgi->param($_);
-          $_ => scalar(@val) > 1 ? \@val : shift(@val)
+          my @val = map { $cgi->unescape( $_ ) } ( $cgi->param($_) );
+          $cgi->unescape($_) => scalar(@val) > 1 ? \@val : shift(@val)
         } $cgi->param
       ),
       (
         map {
           # CGI->Vars joins multi-value params with a null byte.  Which sucks.
           # To avoid that behavior, we do this instead:
-          my @val = $cgi->url_param($_);
-          $_ => scalar(@val) > 1 ? \@val : shift(@val)
+          my @val = map { $cgi->unescape( $_ ) } ( $cgi->url_param($_) );
+          $cgi->unescape($_) => scalar(@val) > 1 ? \@val : shift(@val)
         } $cgi->url_param
       ),
     },
